@@ -1,10 +1,9 @@
 import json
 import os
 from datetime import date, datetime, time, timedelta
-from urllib.parse import urlparse
-
 from dotenv import load_dotenv
 from url_remote.environment_name_enum import EnvironmentName
+from urllib.parse import urlparse
 
 from .mini_logger import MiniLogger as logger
 
@@ -305,13 +304,3 @@ def get_sql_password() -> str:
 
 def remove_digits(text: str) -> str:
     return ''.join([i for i in text if not i.isdigit()])
-
-
-def validate_environment_variables():
-    """This is done for cross variables validation, as single variables are validated by our_get_env.
-    This should be called only once."""
-
-    pass  # No cross validation needed yet
-
-
-validate_environment_variables()
